import 'dart:ui';

import 'common_platform.dart';
import 'package:json_annotation/json_annotation.dart';
import '../sdk_utils.dart';

part 'generic_document_configuration_json.g.dart';

@JsonSerializable(
    includeIfNull: false, createFactory: false, explicitToJson: true)
class GenericDocumentRecognizerJsonConfiguration {
  /// A version of the configuration object
  String? version;

  /// The configuration object should be applied for this screen
  String? screen;

  /// Controls whether the flash should be initially enabled. The default value is FALSE.
  bool? flashEnabled;

  /// UI Interface orientation lock mode
  OrientationLockMode? orientationLockMode;

  /// The preferred camera module (default - BACK)
  CameraModule? cameraModule;

  @JsonKey(toJson: toColorString)

  /// The background color of the top toolbar.
  Color? topBarBackgroundColor;

  @JsonKey(toJson: toColorString)

  /// The color of all active toggle buttons in the toolbar.
  Color? topBarButtonsActiveColor;

  @JsonKey(toJson: toColorString)

  /// The color of all inactive toggle buttons in the toolbar.
  Color? topBarButtonsInactiveColor;

  @JsonKey(toJson: toColorString)

  /// Background color outside of the finder window.
  Color? cameraOverlayColor;

  @JsonKey(toJson: toColorString)

  /// Foreground color of the detection overlay.
  Color? finderLineColor;

  /// Width of finder frame border. Default is 2.
  double? finderLineWidth;

  @JsonKey(toJson: toColorString)

  /// Text color of the fields count label.
  Color? fieldsCountTextColor;

  @JsonKey(toJson: toColorString)

  /// Color of confidence value label background in details screen, when the field confidence level is high.
  Color? fieldConfidenceHighColor;

  @JsonKey(toJson: toColorString)

  /// Color of confidence value label background in details screen, when the field confidence level is moderate.
  Color? fieldConfidenceModerateColor;

  @JsonKey(toJson: toColorString)

  /// Color of confidence value label background in details screen, when the field confidence level is low.
  Color? fieldConfidenceLowColor;

  @JsonKey(toJson: toColorString)

  /// Color of confidence value label text in details.
  Color? fieldConfidenceTextColor;

  @JsonKey(toJson: toColorString)

  /// Color of tip text on scanning screen.
  Color? tipTextColor;

  @JsonKey(toJson: toColorString)

  /// Color of tip background on scanning screen.
  Color? tipBackgroundColor;

  @JsonKey(toJson: toColorString)

  /// The color of bottom sheet
  Color? detailsBackgroundColor;

  @JsonKey(toJson: toColorString)

  /// The color of text elements in bottom sheet
  Color? detailsPrimaryColor;

  @JsonKey(toJson: toColorString)

  /// The color of Submit button
  Color? detailsActionColor;

  @JsonKey(toJson: toColorString)

  /// Text color for section headers on the details screen. iOS only.
  Color? detailsSectionHeaderTextColor;

  @JsonKey(toJson: toColorString)

  /// Background color for section headers on the details screen. iOS only.
  Color? detailsSectionHeaderBackgroundColor;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  /// Whether the cancel button is hidden or not. iOS only.
  bool? cancelButtonHidden;

  /// String used for displaying amount of detected fields. Use %d for number formatting symbol.
  String? clearButtonTitle;

  /// Text of the button which finishes the flow
  String? submitButtonTitle;

  /// String used for displaying amount of detected fields. Use %d for number formatting symbol.
  String? fieldsCountText;

  /// String that shows average confidence value of scanned document. Use %d as number formatting symbol.
  String? confidenceValue;

  /// String that asks user to scan back side of a document.
  String? scanBackSideTitle;

  /// String that asks user to scan front side of a document.
  String? scanFrontSideTitle;

  /// String that asks user to start scanning a document.
  String? startScanningTitle;

  /// String that notifies that both sides of document are scanned.
  String? scannedEverythingTitle;

  /// String being displayed for empty values. iOS only.
  String? emptyValueTitle;

  /// Title of the button that opens the screen where the user can allow the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
  String? enableCameraExplanationText;

  /// A title to show image content. Android only.
  String? imageTitle;

  /// String that notifies that nothing was scanned yet.
  String? noDataTitle;

  /// Accepted document types. All other document types will be ignored. By default - All types
  List<GenericDocumentType>? acceptedDocumentTypes;

  /// Accepted minimal sharpness score. Images with a score less than that will be rejected with RecognitionStatus::ErrorTooBlurry. Default is 80. 0 - any image will be accepted. 80 - a good compromise; the recommended setting. 100 - only very sharp images will be accepted.
  double? sharpnessAcceptanceFactor;

  /// Allows to configure the display configuration for fields.
  List<FieldsDisplayConfiguration>? fieldsDisplayConfiguration;

  /// Allows to configure the display configuration for documents.
  List<DocumentsDisplayConfiguration>? documentsDisplayConfiguration;

  /// List of secure fields which should be excluded from scanning process. All other fields will be scanned as usual. Field should be set ONLY as normalized field name. Example - [DePassport.BirthDate] or [DePassport.Birthplace]
  List<String>? excludedFieldTypes;

  /// Controls whether the flash toggle button is hidden or not.
  bool? flashButtonHidden;

  /// Title of the flash toggle button.
  String? flashButtonTitle;

  /// Controls whether buttons should use all capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
  bool? useButtonsAllCaps;

  /// If `true`, replaces the cancel button in the top bar with a back arrow icon. The default value is FALSE. Android only.
  bool? replaceCancelButtonWithIcon;

  /// Preview mode of the camera. FILL_IN or FIT_IN. Default is FILL_IN. Android only
  CameraPreviewMode? cameraPreviewMode;

  GenericDocumentRecognizerJsonConfiguration({
    this.version,
    this.screen,
    this.flashEnabled,
    this.orientationLockMode,
    this.cameraModule,
    this.topBarBackgroundColor,
    this.topBarButtonsActiveColor,
    this.topBarButtonsInactiveColor,
    this.cameraOverlayColor,
    this.finderLineColor,
    this.finderLineWidth,
    this.fieldsCountTextColor,
    this.fieldConfidenceHighColor,
    this.fieldConfidenceModerateColor,
    this.fieldConfidenceLowColor,
    this.fieldConfidenceTextColor,
    this.tipTextColor,
    this.tipBackgroundColor,
    this.detailsBackgroundColor,
    this.detailsPrimaryColor,
    this.detailsActionColor,
    this.detailsSectionHeaderTextColor,
    this.detailsSectionHeaderBackgroundColor,
    this.cancelButtonTitle,
    this.cancelButtonHidden,
    this.clearButtonTitle,
    this.submitButtonTitle,
    this.fieldsCountText,
    this.confidenceValue,
    this.scanBackSideTitle,
    this.scanFrontSideTitle,
    this.startScanningTitle,
    this.scannedEverythingTitle,
    this.emptyValueTitle,
    this.enableCameraButtonTitle,
    this.enableCameraExplanationText,
    this.imageTitle,
    this.noDataTitle,
    this.acceptedDocumentTypes,
    this.sharpnessAcceptanceFactor,
    this.fieldsDisplayConfiguration,
    this.documentsDisplayConfiguration,
    this.excludedFieldTypes,
    this.flashButtonHidden,
    this.flashButtonTitle,
    this.useButtonsAllCaps,
    this.replaceCancelButtonWithIcon,
    this.cameraPreviewMode,
  });

  Map<String, dynamic> toJson() =>
      _$GenericDocumentRecognizerJsonConfigurationToJson(this);
}

/// Field display configuration object
@JsonSerializable(
    includeIfNull: false, createFactory: false, explicitToJson: true)
class FieldsDisplayConfiguration {
  /// Complete list of available normalized field names is available in the documentation
  String normalizedFieldName;

  /// The display text of the field in the list
  String defaultDisplayText;

  /// The default display state of a field in the RTU UI, could be hidden by default or visible by default.
  FieldDisplayState defaultDisplayState;
  FieldsDisplayConfiguration(
    this.normalizedFieldName,
    this.defaultDisplayText,
    this.defaultDisplayState,
  );

  Map<String, dynamic> toJson() => _$FieldsDisplayConfigurationToJson(this);
}

/// Field display configuration object
@JsonSerializable(
    includeIfNull: false, createFactory: false, explicitToJson: true)
class DocumentsDisplayConfiguration {
  /// Complete list of available normalized document names is available in the documentation
  String normalizedDocumentName;

  /// The display text of the document in the list
  String defaultDisplayText;
  DocumentsDisplayConfiguration(
    this.normalizedDocumentName,
    this.defaultDisplayText,
  );

  Map<String, dynamic> toJson() => _$DocumentsDisplayConfigurationToJson(this);
}

/// Field display state in the RTU UI
enum FieldDisplayState {
  /// Field will not be shown in the RTU UI */
  HIDDEN,

  /// Field will be shown in the RTU UI if its text value isn't an empty string */
  VISIBLE_IF_NOT_EMPTY,

  /// Field will be shown in the RTU UI */
  ALWAYS_VISIBLE,
}

/// Supported document types
enum GenericDocumentType {
  /// German ID card, front side */
  DE_ID_CARD_FRONT,

  /// German ID card, back side */
  DE_ID_CARD_BACK,

  /// German travel passport (Reisepass) */
  DE_PASSPORT,

  /// German driver license (Führerschein), front side */
  DE_DRIVER_LICENSE_FRONT,

  /// German driver license (Führerschein), back side */
  DE_DRIVER_LICENSE_BACK,
}
