import 'dart:ui';

import 'common_platform.dart';
import 'package:json_annotation/json_annotation.dart';
import '../sdk_utils.dart';

part 'mrz_configuration_json.g.dart';

@JsonSerializable(
    includeIfNull: false, createFactory: false, explicitToJson: true)
class MrzScannerJsonConfiguration {
  /// A version of the configuration object
  String? version;

  /// The configuration object should be applied for this screen
  String? screen;

  /// The preferred camera module (default - BACK)
  CameraModule? cameraModule;

  @JsonKey(toJson: toColorString)

  /// Background color outside of the finder window.
  Color? cameraOverlayColor;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  /// Whether the cancel button is hidden or not. iOS only.
  bool? cancelButtonHidden;

  /// Title of the button that opens the screen where the user can allow the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
  String? enableCameraExplanationText;

  @JsonKey(toJson: toColorString)

  /// Foreground color of the detection overlay.
  Color? finderLineColor;

  /// Width of finder frame border. Default is 2.
  double? finderLineWidth;

  /// String being displayed as description.
  String? finderTextHint;

  @JsonKey(toJson: toColorString)

  /// Foreground color of the description label.
  Color? finderTextHintColor;

  /// Aspect ratio of finder frame (width \ height), which is used to build actual finder frame. Default is 7 - which is good for standard machine readable zones.
  AspectRatio? finderAspectRatio;

  /// Controls whether the flash toggle button is hidden or not.
  bool? flashButtonHidden;

  /// Title of the flash toggle button.
  String? flashButtonTitle;

  /// Controls whether the flash should be initially enabled. The default value is FALSE.
  bool? flashEnabled;

  /// UI Interface orientation lock mode
  OrientationLockMode? orientationLockMode;

  /// Controls whether to play a beep sound after a successful detection. Default value is TRUE.
  bool? successBeepEnabled;

  @JsonKey(toJson: toColorString)

  /// The background color of the top toolbar.
  Color? topBarBackgroundColor;

  @JsonKey(toJson: toColorString)

  /// The color of all active toggle buttons in the toolbar.
  Color? topBarButtonsActiveColor;

  @JsonKey(toJson: toColorString)

  /// The color of all inactive toggle buttons in the toolbar.
  Color? topBarButtonsInactiveColor;

  /// Controls whether buttons should use all capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
  bool? useButtonsAllCaps;

  /// If `true`, replaces the cancel button in the top bar with a back arrow icon. The default value is FALSE. Android only.
  bool? replaceCancelButtonWithIcon;

  /// Preview mode of the camera. FILL_IN or FIT_IN. Default is FILL_IN. Android only
  CameraPreviewMode? cameraPreviewMode;

  /// Time in seconds until the screen is automatically cancelled. Set to 0 to disable automatic cancellation. Defaults to 0 (disabled). iOS only.
  double? autoCancelTimeout;

  MrzScannerJsonConfiguration({
    this.version,
    this.screen,
    this.cameraModule,
    this.cameraOverlayColor,
    this.cancelButtonTitle,
    this.cancelButtonHidden,
    this.enableCameraButtonTitle,
    this.enableCameraExplanationText,
    this.finderLineColor,
    this.finderLineWidth,
    this.finderTextHint,
    this.finderTextHintColor,
    this.finderAspectRatio,
    this.flashButtonHidden,
    this.flashButtonTitle,
    this.flashEnabled,
    this.orientationLockMode,
    this.successBeepEnabled,
    this.topBarBackgroundColor,
    this.topBarButtonsActiveColor,
    this.topBarButtonsInactiveColor,
    this.useButtonsAllCaps,
    this.replaceCancelButtonWithIcon,
    this.cameraPreviewMode,
    this.autoCancelTimeout,
  });

  Map<String, dynamic> toJson() => _$MrzScannerJsonConfigurationToJson(this);
}
