import 'package:json_annotation/json_annotation.dart';
import 'json/license_plate_configuration_json.dart';

import 'json/common.dart';
export 'json/license_plate_configuration_json.dart';
part 'license_plate_scan_data.g.dart';

/// Result of license plate scanning
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class LicensePlateScanResult extends Result {
  /// The country code of the license plate
  String countryCode = '';

  /// The number on the license plate
  String licensePlate = '';

  /// The raw detected text
  String rawText = '';

  /// The confidence of the recognition
  double confidence = 0;

  LicensePlateScanResult(
      {this.countryCode = '',
      this.licensePlate = '',
      this.rawText = '',
      this.confidence = 0.0});

  LicensePlateScanResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  LicensePlateScanResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory LicensePlateScanResult.fromJson(Map<String, dynamic> json) =>
      _$LicensePlateScanResultFromJson(json);

  Map<String, dynamic> toJson() => _$LicensePlateScanResultToJson(this);
}

/// License plate rtu-ui scanner configuration class
class LicensePlateScannerConfiguration
    extends LicensePlateScannerJsonConfiguration {
  /// The configuration object should be applied for this screen
  @override
  String? screen = "LicensePlateScanner";

  LicensePlateScannerConfiguration({
    super.cameraModule,
    super.cameraOverlayColor,
    super.cancelButtonTitle,
    super.cancelButtonHidden,
    super.confirmationDialogStyle,
    super.confirmationDialogConfirmButtonStyle,
    super.confirmationDialogRetryButtonStyle,
    super.enableCameraButtonTitle,
    super.enableCameraExplanationText,
    super.finderLineColor,
    super.finderLineWidth,
    super.finderTextHint,
    super.finderTextHintColor,
    super.finderPreferredHeight,
    super.flashButtonHidden,
    super.flashButtonTitle,
    super.flashEnabled,
    super.orientationLockMode,
    super.topBarBackgroundColor,
    super.topBarButtonsActiveColor,
    super.topBarButtonsInactiveColor,
    super.minNumberOfRequiredFramesWithEqualRecognitionResult,
    super.maximumNumberOfAccumulatedFrames,
    super.useButtonsAllCaps,
    super.significantShakeDelay,
    super.scanStrategy,
    super.confirmationDialogTitle,
    super.confirmationDialogMessage,
    super.confirmationDialogConfirmButtonTitle,
    super.confirmationDialogRetryButtonTitle,
    super.confirmationDialogAccentColor,
    super.confirmationDialogConfirmButtonFilled,
    super.confirmationDialogConfirmButtonFilledTextColor,
    super.replaceCancelButtonWithIcon,
    super.cameraPreviewMode,
  });
}
